@@ -27,9 +27,14 @@ def get_inference_client(*, model_name, project_name, model_version_id):
 
 
 class ModelInferenceClient:
+    STAGE = from_config(
+        key="STAGE",
+        default="staging",
+    )
+
     BASE_URL = from_config(
         key="BASE_URL",
-        default="https://6zacu5yc29.execute-api.us-east-1.amazonaws.com/development",
+        default=f"https://api.slai.io/{STAGE}",
     )
 
     def __init__(self, *, model_name, project_name, model_version_id=None):
@@ -57,6 +62,9 @@ class ModelInferenceClient:
             "payload": payload,
         }
 
+        if body.get("model_version_id") is None:
+            del body["model_version_id"]
+
         res = requests.post(
             f"{self.BASE_URL}/model/call",
             auth=HTTPBasicAuth(self.client_id, self.client_secret),
