@@ -89,8 +89,10 @@ class ModelVersion:
         )
 
         return_code = _subprocess.call(
-            f"jupyter nbconvert {notebook_path} --to=python", shell=True
+            f"/workspace/env/{self.model_name}/bin/python -m jupyter nbconvert {notebook_path} --to=python",  # noqa
+            shell=True,
         )
+
         if return_code != 0:
             raise UnableToConvertNotebook("could_not_convert_notebook")
 
